@@ -177,17 +177,21 @@ sub chordpro {
     # command line as well, but don't tell anybody.
     foreach my $file ( @ARGV ) {
 	my $opts;
-	if ( $file =~ /(^|\s)--(?:meta|config)\b/ ) {
+	if ( $file =~ /(^|\s)--(?:meta|config|define)\b/ ) {
 	    # Break into words.
 	    my @w = Text::ParseWords::shellwords($file);
 	    my %meta;
+	    my %defs;
 	    my @cfg;
 	    die("Error in filelist: $file\n")
 	      unless Getopt::Long::GetOptionsFromArray
-	      ( \@w, 'config=s@' => \@cfg, 'meta=s%' => \%meta )
+	      ( \@w, 'config=s@' => \@cfg, 'meta=s%' => \%meta,
+		'define=s%' => \%defs,
+	      )
 	      && @w == 1;
 	    $file = $w[0];
-	    $opts = { meta => { map { $_, [ $meta{$_} ] } keys %meta } };
+	    $opts = { meta => { map { $_, [ $meta{$_} ] } keys %meta },
+		      defs => \%defs };
 	    if ( @cfg ) {
 		$opts->{meta}->{__config} = \@cfg;
 	    }
@@ -256,11 +260,13 @@ sub chordpro {
         if ( $of && $of ne "-" ) {
             open( my $fd, '>', $of );
 	    binmode( $fd, ":utf8" );
+	    push( @$res, '' ) unless $res->[-1] eq '';
 	    print { $fd } ( join( "\n", @$res ) );
 	    close($fd);
         }
 	else {
 	    binmode( STDOUT, ":utf8" );
+	    push( @$res, '' ) unless $res->[-1] eq '';
 	    print( join( "\n", @$res ) );
 	}
 	# Don't close STDOUT!
@@ -990,7 +996,17 @@ sub app_setup {
 		push( @files, encode_utf8($_) );
 	    }
 	}
-	unshift( @ARGV, @files );
+	if ( @files ) {
+	    if ( $files[0] =~ /\.pdf$/i ) {
+		$options->{'front-matter'} //= $files[0];
+		shift(@files);
+	    }
+	    if ( $files[-1] =~ /\.pdf$/i ) {
+		$options->{'back-matter'} //= $files[-1];
+		pop(@files);
+	    }
+	}
+	unshift( @ARGV, @files ) if @files;
     }
 
     # At this point, there should be filename argument(s)
@@ -1135,15 +1151,19 @@ Options:
     --a2crd                       Perform text to ChordPro conversion only
     --noa2crd                     Do not auto-sense text to ChordPro conversion
     --about  -A                   About ChordPro...
+    --back-matter=FILE            Add back matter pages from PDF document
     --config=JSON  --cfg          Config definitions (multiple)
     --cover=FILE                  Add cover pages from PDF document
     --crd                         Input is text, not ChordPro
+    --csv                         (with PDF) Also generate CSV
     --decapo                      Eliminate capo settings
     --diagrams=WHICH		  Prints chord diagrams
     --encoding=ENC                Encoding for input files (UTF-8)
     --filelist=FILE               Reads song file names from FILE
     --fragment -F                 Partial (incomplete) song
+    --front-matter=FILE           Add cover pages from PDF document
     --lyrics-only  -l             Only prints lyrics
+    --meta KEY=VALUE              Add meta data
     --output=FILE  -o             Saves the output to FILE
     --[no]strict                  Strict conformance
     --start-page-number=N  -p     Starting page number [1]
@@ -1177,25 +1197,26 @@ Options marked with - are ignored.
 
 Configuration options:
     --config=CFG        Project specific config file ($cfg{config})
-    --noconfig          Don't use a project specific config file
-    --nosongconfig      Don't use song specific configs
-    --userconfig=CFG    User specific config file ($cfg{userconfig})
-    --nouserconfig      Don't use a user specific config file
-    --sysconfig=CFG     System specific config file ($cfg{sysconfig})
-    --nosysconfig       Don't use a system specific config file
-    --nodefaultconfigs  -X  Don't use any default config files
     --define=XXX=YYY	Sets config item XXX to value YYY
+    --noconfig          Don't use a project specific config file
+    --nodefaultconfigs  -X  Don't use any default config files
+    --nosongconfig      Don't use song specific configs
+    --nosysconfig       Don't use a system specific config file
+    --nouserconfig      Don't use a user specific config file
     --print-default-config   Prints the default config and exits
-    --print-final-config   Prints the resultant config and exits
     --print-delta-config   Prints the diffs for the resultant config and exits
+    --print-final-config   Prints the resultant config and exits
+    --reference  -R     Reference mode (no configs etc.)
+    --sysconfig=CFG     System specific config file ($cfg{sysconfig})
+    --userconfig=CFG    User specific config file ($cfg{userconfig})
 Missing default configuration files are silently ignored.
 
 Miscellaneous options:
     --help  -h          This message
     --help-config       Help for ChordPro configuration
-    --manual            The full manual.
     --ident             Show identification
-    --verbose           Verbose information
+    --manual            The full manual.
+    --verbose           Verbose information. Repeat for more.
 EndOfUsage
     exit $exit if defined $exit;
 }
