@@ -15,6 +15,7 @@ use App::Packager;
 use File::Temp ();
 use Storable qw(dclone);
 use List::Util qw(any);
+use Carp;
 use feature 'state';
 
 use App::Music::ChordPro::Output::Common
@@ -364,8 +365,12 @@ sub generate_song {
     my $ps = $::config->clone->{pdf};
     $ps->{pr} = $pr;
     $pr->{ps} = $ps;
+    $pr->{_df} = {};
+#    warn("X1: ", $ps->{fonts}->{$_}->{size}, "\n") for "text";
     $pr->init_fonts();
     my $fonts = $ps->{fonts};
+    $pr->{_df}->{$_} = { %{$fonts->{$_}} } for qw( text chord grid toc tab );
+#    warn("X2: ", $pr->{_df}->{$_}->{size}, "\n") for "text";
 
     $structured = ( $options->{'backend-option'}->{structure} // '' ) eq 'structured';
     $s->structurize if $structured;
@@ -648,7 +653,7 @@ sub generate_song {
 
     my $chorddiagrams = sub {
 	my ( $chords, $show, $ldisp ) = @_;
-	return unless $dctl->{show};
+	return if $lyrics_only || !$dctl->{show};
 	my @chords;
 	$chords = $s->{chords}->{chords}
 	  if !defined($chords) && $s->{chords};
@@ -1036,6 +1041,8 @@ sub generate_song {
 
 	if ( $elt->{type} eq "gridline" ) {
 
+	    next if $lyrics_only || !$ps->{grids}->{show};
+
 	    my $vsp = grid_vsp( $elt, $ps );
 	    $checkspace->($vsp);
 	    $pr->show_vpos( $y, 0 ) if $config->{debug}->{spacing};
@@ -1277,23 +1284,27 @@ sub generate_song {
 		else {
 		    # Restore default.
 		    $ps->{fonts}->{$1}->{size} =
-		      $::config->{pdf}->{fonts}->{$1}->{size};
+		      $pr->{_df}->{$1}->{size};
 		}
 	    }
 	    elsif ( $elt->{name} =~ /^(text|chord|grid|toc|tab)-font$/ ) {
 		my $f = $1;
 		if ( defined $elt->{value} ) {
-		    if ( $elt->{value} =~ m;/;
+		    my ( $fn, $sz ) = $elt->{value} =~ /^(.*) (\d+(?:\.\d+)?)$/;
+		    $fn //= $elt->{value};
+		    if ( $fn =~ m;/;
 			 ||
-			 $elt->{value} =~ m;\.(ttf|otf)$;i ) {
+			 $fn =~ m;\.(ttf|otf)$;i ) {
 			delete $ps->{fonts}->{$f}->{description};
 			delete $ps->{fonts}->{$f}->{name};
 			$ps->{fonts}->{$f}->{file} = $elt->{value};
+			# Discard $sz. There will be an {xxxsize} following.
 		    }
-		    elsif ( is_corefont( $elt->{value} ) ) {
+		    elsif ( is_corefont( $fn ) ) {
 			delete $ps->{fonts}->{$f}->{description};
 			delete $ps->{fonts}->{$f}->{file};
-			$ps->{fonts}->{$f}->{name} = is_corefont( $elt->{value} );
+			$ps->{fonts}->{$f}->{name} = is_corefont($fn);
+			# Discard $sz. There will be an {xxxsize} following.
 		    }
 		    else {
 			delete $ps->{fonts}->{$f}->{file};
@@ -1304,7 +1315,7 @@ sub generate_song {
 		else {
 		    # Restore default.
 		    $ps->{fonts}->{$f} =
-		      { %{ $::config->{pdf}->{fonts}->{$f} } };
+		      { %{ $pr->{_df}->{$f} } };
 		}
 		$pr->init_font($f);
 	    }
@@ -1315,7 +1326,7 @@ sub generate_song {
 		else {
 		    # Restore default.
 		    $ps->{fonts}->{$1}->{color} =
-		      $::config->{pdf}->{fonts}->{$1}->{color};
+		      $pr->{_df}->{$1}->{color};
 		}
 	    }
 	    next;
@@ -1627,9 +1638,26 @@ sub songline {
 	$x += $opts{indent} if $opts{indent};
 	$x += $elt->{indent} if $elt->{indent};
 	prlabel( $ps, $tag, $x, $ytext );
-	my ( $text, $ex ) = wrapsimple( $pr, $elt->{text}, $x, $ftext );
+	my $t = $elt->{text};
+	if ( $elt->{chords} ) {
+	    $t = "";
+	    my @ph = @{ $elt->{phrases} };
+	    for my $chord ( @{ $elt->{chords} }) {
+		if ( $chord eq '' ) {
+		}
+		else {
+		    my $info = $opts{song}->{chordsinfo}->{$chord};
+		    croak("Missing info for chord $chord") unless $info;
+		    $chord = $info->chord_display( has_musicsyms($ftext) );
+		}
+		$t .= $chord . shift(@ph);
+	    }
+	}
+	my ( $text, $ex ) = wrapsimple( $pr, $t, $x, $ftext );
 	$pr->text( $text, $x, $ytext, $ftext );
-	return $ex ne "" ? { %$elt, indent => $pr->strwidth("x"), text => $ex } : undef;
+	return $ex ne ""
+	  ? { %$elt, indent => $pr->strwidth("x"), text => $ex, chords => undef  }
+	  : undef;
     }
     if ( $type eq "tabline" ) {
 	$ftext = $fonts->{tab};
